<?php
/**
 * Feedname Wordpress Plugin
 *
 * Add the Name of the Blog to the Author inside Feeds.
 * 
 * mask placeholders:
 *   - %author%    original author name
 *   - %blog-name% name of the blog 
 * 
 * @version 0.1
 * @license Gnu Public License 3
 * @author  Hans Krentel <hanskrentel@yahoo.de>
 */

/*
Plugin Name: Feedname
Plugin URI: http://subfiles.net/wordpress/plugins/feedname/
Description: Add the Name of your Blog to the Author inside Feeds
Author: Hans Krentel
Version: 0.1
Author URI: http://subfiles.net/
*/



/**
 * Feedname Plugin Class
 */
class Feedname_Plugin
{
	/**
	 * local store for the mask
	 *
	 * @var string
	 */
	protected $_mask = '%author% (%blog-name%)';
	
	/**
	 * constructor
	 * 
	 * register the plugin class with wordpress
	 * 
	 * @param string $mask optional mask parameter	 
	 */
	public function __construct($mask = null)
	{
		// configure instance
		if ($mask)
		{
			$this->_mask = (string) $mask;
		}
		
		// register 'the_author' filter		
		add_action('the_author', array($this, 'the_author'));					
	}
	
	/**
	 * callback for wp-api-filter 'the_author'
	 * 
	 * this filter will add 
	 *
	 * @param  sting  $author Author of the current Post
	 * @return string Filtered Author value
	 */
	public function the_author($author)
	{	
		// if this is not a feed, quit directly
		if (!is_feed())
		{
			return $author;
		}
		
		/* build feed author */
		
		$build = $this->_mask;
 			
 		$build = str_replace('%author%', $author, $build);
 			
 		$build = str_replace('%blog-name%', get_bloginfo_rss('name'), $build);
 			
 		return $build;
	} 
	
} // class

// Instantiate the Plugin
$pluginFeedname = new Feedname_Plugin();
